@@ -1,20 +1,15 @@
+
 /* GDBM module using dictionary interface */
 /* Author: Anthony Baxter, after dbmmodule.c */
 /* Doc strings: Mitch Chapman */
 
-// clinic/_gdbmmodule.c.h uses internal pycore_modsupport.h API
-#ifndef Py_BUILD_CORE_BUILTIN
-#  define Py_BUILD_CORE_MODULE 1
-#endif
-
+#define PY_SSIZE_T_CLEAN
 #include "Python.h"
-#include "pycore_pyerrors.h"        // _PyErr_SetLocaleString()
-#include "gdbm.h"
 
-#include <fcntl.h>
-#include <stdlib.h>                 // free()
-#include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include "gdbm.h"
 
 #if defined(WIN32) && !defined(__CYGWIN__)
 #include "gdbmerrno.h"
@@ -34,24 +29,6 @@ get_gdbm_state(PyObject *module)
     return (_gdbm_state *)state;
 }
 
-/*
- * Set the gdbm error obtained by gdbm_strerror(gdbm_errno).
- *
- * If no error message exists, a generic (UTF-8) error message
- * is used instead.
- */
-static void
-set_gdbm_error(_gdbm_state *state, const char *generic_error)
-{
-    const char *gdbm_errmsg = gdbm_strerror(gdbm_errno);
-    if (gdbm_errmsg) {
-        _PyErr_SetLocaleString(state->gdbm_error, gdbm_errmsg);
-    }
-    else {
-        PyErr_SetString(state->gdbm_error, generic_error);
-    }
-}
-
 /*[clinic input]
 module _gdbm
 class _gdbm.gdbm "gdbmobject *" "&Gdbmtype"
@@ -110,7 +87,7 @@ newgdbmobject(_gdbm_state *state, const char *file, int flags, int mode)
             PyErr_SetFromErrnoWithFilename(state->gdbm_error, file);
         }
         else {
-            set_gdbm_error(state, "gdbm_open() error");
+            PyErr_SetString(state->gdbm_error, gdbm_strerror(gdbm_errno));
         }
         Py_DECREF(dp);
         return NULL;
@@ -155,7 +132,7 @@ gdbm_length(gdbmobject *dp)
                 PyErr_SetFromErrno(state->gdbm_error);
             }
             else {
-                set_gdbm_error(state, "gdbm_count() error");
+                PyErr_SetString(state->gdbm_error, gdbm_strerror(gdbm_errno));
             }
             return -1;
         }
@@ -184,35 +161,6 @@ gdbm_length(gdbmobject *dp)
     return dp->di_size;
 }
 
-static int
-gdbm_bool(gdbmobject *dp)
-{
-    _gdbm_state *state = PyType_GetModuleState(Py_TYPE(dp));
-    if (dp->di_dbm == NULL) {
-        PyErr_SetString(state->gdbm_error, "GDBM object has already been closed");
-        return -1;
-    }
-    if (dp->di_size > 0) {
-        /* Known non-zero size. */
-        return 1;
-    }
-    if (dp->di_size == 0) {
-        /* Known zero size. */
-        return 0;
-    }
-    /* Unknown size.  Ensure DBM object has an entry. */
-    datum key = gdbm_firstkey(dp->di_dbm);
-    if (key.dptr == NULL) {
-        /* Empty. Cache this fact. */
-        dp->di_size = 0;
-        return 0;
-    }
-
-    /* Non-empty. Don't cache the length since we don't know. */
-    free(key.dptr);
-    return 1;
-}
-
 // Wrapper function for PyArg_Parse(o, "s#", &d.dptr, &d.size).
 // This function is needed to support PY_SSIZE_T_CLEAN.
 // Return 1 on success, same to PyArg_Parse().
@@ -278,7 +226,8 @@ _gdbm_gdbm_get_impl(gdbmobject *self, PyObject *key, PyObject *default_value)
     res = gdbm_subscript(self, key);
     if (res == NULL && PyErr_ExceptionMatches(PyExc_KeyError)) {
         PyErr_Clear();
-        return Py_NewRef(default_value);
+        Py_INCREF(default_value);
+        return default_value;
     }
     return res;
 }
@@ -305,7 +254,7 @@ gdbm_ass_sub(gdbmobject *dp, PyObject *v, PyObject *w)
                 PyErr_SetObject(PyExc_KeyError, v);
             }
             else {
-                set_gdbm_error(state, "gdbm_delete() error");
+                PyErr_SetString(state->gdbm_error, gdbm_strerror(gdbm_errno));
             }
             return -1;
         }
@@ -316,12 +265,11 @@ gdbm_ass_sub(gdbmobject *dp, PyObject *v, PyObject *w)
         }
         errno = 0;
         if (gdbm_store(dp->di_dbm, krec, drec, GDBM_REPLACE) < 0) {
-            if (errno != 0) {
+            if (errno != 0)
                 PyErr_SetFromErrno(state->gdbm_error);
-            }
-            else {
-                set_gdbm_error(state, "gdbm_store() error");
-            }
+            else
+                PyErr_SetString(state->gdbm_error,
+                                gdbm_strerror(gdbm_errno));
             return -1;
         }
     }
@@ -509,8 +457,8 @@ to create a list in memory that contains them all:
 
 static PyObject *
 _gdbm_gdbm_nextkey_impl(gdbmobject *self, PyTypeObject *cls, const char *key,
-                        Py_ssize_t key_length)
-/*[clinic end generated code: output=c81a69300ef41766 input=365e297bc0b3db48]*/
+                        Py_ssize_clean_t key_length)
+/*[clinic end generated code: output=204964441fdbaf02 input=365e297bc0b3db48]*/
 {
     PyObject *v;
     datum dbm_key, nextkey;
@@ -554,12 +502,10 @@ _gdbm_gdbm_reorganize_impl(gdbmobject *self, PyTypeObject *cls)
     check_gdbmobject_open(self, state->gdbm_error);
     errno = 0;
     if (gdbm_reorganize(self->di_dbm) < 0) {
-        if (errno != 0) {
+        if (errno != 0)
             PyErr_SetFromErrno(state->gdbm_error);
-        }
-        else {
-            set_gdbm_error(state, "gdbm_reorganize() error");
-        }
+        else
+            PyErr_SetString(state->gdbm_error, gdbm_strerror(gdbm_errno));
         return NULL;
     }
     Py_RETURN_NONE;
@@ -587,47 +533,18 @@ _gdbm_gdbm_sync_impl(gdbmobject *self, PyTypeObject *cls)
     Py_RETURN_NONE;
 }
 
-/*[clinic input]
-_gdbm.gdbm.clear
-    cls: defining_class
-    /
-Remove all items from the database.
-
-[clinic start generated code]*/
-
-static PyObject *
-_gdbm_gdbm_clear_impl(gdbmobject *self, PyTypeObject *cls)
-/*[clinic end generated code: output=673577c573318661 input=34136d52fcdd4210]*/
-{
-    _gdbm_state *state = PyType_GetModuleState(cls);
-    assert(state != NULL);
-    check_gdbmobject_open(self, state->gdbm_error);
-    datum key;
-    // Invalidate cache
-    self->di_size = -1;
-    while (1) {
-        key = gdbm_firstkey(self->di_dbm);
-        if (key.dptr == NULL) {
-            break;
-        }
-        if (gdbm_delete(self->di_dbm, key) < 0) {
-            PyErr_SetString(state->gdbm_error, "cannot delete item from database");
-            return NULL;
-        }
-    }
-    Py_RETURN_NONE;
-}
-
 static PyObject *
 gdbm__enter__(PyObject *self, PyObject *args)
 {
-    return Py_NewRef(self);
+    Py_INCREF(self);
+    return self;
 }
 
 static PyObject *
 gdbm__exit__(PyObject *self, PyObject *args)
 {
-    return _gdbm_gdbm_close_impl((gdbmobject *)self);
+    _Py_IDENTIFIER(close);
+    return _PyObject_CallMethodIdNoArgs(self, &PyId_close);
 }
 
 static PyMethodDef gdbm_methods[] = {
@@ -639,7 +556,6 @@ static PyMethodDef gdbm_methods[] = {
     _GDBM_GDBM_SYNC_METHODDEF
     _GDBM_GDBM_GET_METHODDEF
     _GDBM_GDBM_SETDEFAULT_METHODDEF
-    _GDBM_GDBM_CLEAR_METHODDEF
     {"__enter__", gdbm__enter__, METH_NOARGS, NULL},
     {"__exit__",  gdbm__exit__, METH_VARARGS, NULL},
     {NULL,              NULL}           /* sentinel */
@@ -653,7 +569,6 @@ static PyType_Slot gdbmtype_spec_slots[] = {
     {Py_mp_length, gdbm_length},
     {Py_mp_subscript, gdbm_subscript},
     {Py_mp_ass_subscript, gdbm_ass_sub},
-    {Py_nb_bool, gdbm_bool},
     {Py_tp_doc, (char*)gdbm_object__doc__},
     {0, 0}
 };
@@ -675,7 +590,7 @@ static PyType_Spec gdbmtype_spec = {
 /*[clinic input]
 _gdbm.open as dbmopen
 
-    filename: object
+    filename: unicode
     flags: str="r"
     mode: int(py_default="0o666") = 0o666
     /
@@ -707,7 +622,7 @@ when the database has to be created.  It defaults to octal 0o666.
 static PyObject *
 dbmopen_impl(PyObject *module, PyObject *filename, const char *flags,
              int mode)
-/*[clinic end generated code: output=9527750f5df90764 input=bca6ec81dc49292c]*/
+/*[clinic end generated code: output=9527750f5df90764 input=812b7d74399ceb0e]*/
 {
     int iflags;
     _gdbm_state *state = get_gdbm_state(module);
@@ -732,6 +647,7 @@ dbmopen_impl(PyObject *module, PyObject *filename, const char *flags,
         return NULL;
     }
     for (flags++; *flags != '\0'; flags++) {
+        char buf[40];
         switch (*flags) {
 #ifdef GDBM_FAST
             case 'f':
@@ -749,17 +665,17 @@ dbmopen_impl(PyObject *module, PyObject *filename, const char *flags,
                 break;
 #endif
             default:
-                PyErr_Format(state->gdbm_error,
-                             "Flag '%c' is not supported.", (unsigned char)*flags);
+                PyOS_snprintf(buf, sizeof(buf), "Flag '%c' is not supported.",
+                              *flags);
+                PyErr_SetString(state->gdbm_error, buf);
                 return NULL;
         }
     }
 
-    PyObject *filenamebytes;
-    if (!PyUnicode_FSConverter(filename, &filenamebytes)) {
+    PyObject *filenamebytes = PyUnicode_EncodeFSDefault(filename);
+    if (filenamebytes == NULL) {
         return NULL;
     }
-
     const char *name = PyBytes_AS_STRING(filenamebytes);
     if (strlen(name) != (size_t)PyBytes_GET_SIZE(filenamebytes)) {
         Py_DECREF(filenamebytes);
@@ -813,7 +729,11 @@ _gdbm_exec(PyObject *module)
     defined(GDBM_VERSION_PATCH)
     PyObject *obj = Py_BuildValue("iii", GDBM_VERSION_MAJOR,
                                   GDBM_VERSION_MINOR, GDBM_VERSION_PATCH);
-    if (PyModule_Add(module, "_GDBM_VERSION", obj) < 0) {
+    if (obj == NULL) {
+        return -1;
+    }
+    if (PyModule_AddObject(module, "_GDBM_VERSION", obj) < 0) {
+        Py_DECREF(obj);
         return -1;
     }
 #endif
@@ -846,8 +766,6 @@ _gdbm_module_free(void *module)
 
 static PyModuleDef_Slot _gdbm_module_slots[] = {
     {Py_mod_exec, _gdbm_exec},
-    {Py_mod_multiple_interpreters, Py_MOD_PER_INTERPRETER_GIL_SUPPORTED},
-    {Py_mod_gil, Py_MOD_GIL_NOT_USED},
     {0, NULL}
 };
 
