@@ -1,8 +1,7 @@
 """Tests for distutils.unixccompiler."""
 import sys
 import unittest
-from test.support import run_unittest
-from test.support.os_helper import EnvironmentVarGuard
+from test.support import EnvironmentVarGuard, run_unittest
 
 from distutils import sysconfig
 from distutils.unixccompiler import UnixCCompiler
@@ -12,7 +11,6 @@ class UnixCCompilerTestCase(unittest.TestCase):
     def setUp(self):
         self._backup_platform = sys.platform
         self._backup_get_config_var = sysconfig.get_config_var
-        self._backup_config_vars = dict(sysconfig._config_vars)
         class CompilerWrapper(UnixCCompiler):
             def rpath_foo(self):
                 return self.runtime_library_dir_option('/foo')
@@ -21,8 +19,6 @@ class UnixCCompilerTestCase(unittest.TestCase):
     def tearDown(self):
         sys.platform = self._backup_platform
         sysconfig.get_config_var = self._backup_get_config_var
-        sysconfig._config_vars.clear()
-        sysconfig._config_vars.update(self._backup_config_vars)
 
     @unittest.skipIf(sys.platform == 'win32', "can't test on Windows")
     def test_runtime_libdir_option(self):
@@ -55,6 +51,14 @@ class UnixCCompilerTestCase(unittest.TestCase):
 
         sysconfig.get_config_var = old_gcv
 
+        # irix646
+        sys.platform = 'irix646'
+        self.assertEqual(self.cc.rpath_foo(), ['-rpath', '/foo'])
+
+        # osf1V5
+        sys.platform = 'osf1V5'
+        self.assertEqual(self.cc.rpath_foo(), ['-rpath', '/foo'])
+
         # GCC GNULD
         sys.platform = 'bar'
         def gcv(v):
@@ -139,7 +143,7 @@ class UnixCCompilerTestCase(unittest.TestCase):
 
 
 def test_suite():
-    return unittest.TestLoader().loadTestsFromTestCase(UnixCCompilerTestCase)
+    return unittest.makeSuite(UnixCCompilerTestCase)
 
 if __name__ == "__main__":
     run_unittest(test_suite())
